@@ -40,6 +40,6 @@ int main(int argc, char *argv[])
  //   QObject::connect(adaptor, SIGNAL(settingsRequested()), &w, SLOT(showSettingsDialog()));
     w.show();
 
-    app.exec();
+    return app.exec();
 }
 
